@@ -1,43 +1,42 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
+;<font size="-3"><pre>
 ;*=====================================================================*/
 ;*    .../prgm/project/bigloo/examples/Yacc2bigloo/yacc2bigloo.scm     */
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Mon Nov 27 09:54:26 1995                          */
-;*    Last change :  Thu Nov 30 09:55:57 1995 (serrano)                */
+;*    Last change :  Mon Jan 18 21:02:22 1999 (serrano)                */
 ;*    -------------------------------------------------------------    */
 ;*    The `Yacc grammar -> Bigloo grammar' translator                  */
 ;*=====================================================================*/
@@ -65,7 +64,7 @@
    (yacc->bigloo))
 
 ;*---------------------------------------------------------------------*/
-;*    yacc->bigloo ...                                                  */
+;*    yacc->bigloo ...                                                 */
 ;*---------------------------------------------------------------------*/
 (define (yacc->bigloo)
    (if (string? *dest*)
@@ -178,17 +177,17 @@
 ;*    token-reader ...                                                 */
 ;*---------------------------------------------------------------------*/
 (define token-reader
-   (regular-grammar ((letter (or #\_ (inside #\a #\z #\A #\Z)))
-		     (digit  (inside #\0 #\9)))
+   (regular-grammar ((letter (or #\_ (uncase (in ("az")))))
+		     (digit  (in ("09"))))
       ((+ (in #\space #\newline))
 	  (ignore))
 
       ;; comment
-      (("/*" (* (or (out #\*) (#\* (out #\/)))) #\* #\/)
+      ((: "/*" (* (or (out #\*) (: #\* (out #\/)))) #\* #\/)
        (ignore))
 
       ;; identifier
-      (((or #\_ letter) (* (or #\_ letter #\_ digit)))
+      ((: (or #\_ letter) (* (or #\_ letter #\_ digit)))
        (add-token! (the-string))
        (ignore))
 
@@ -200,42 +199,42 @@
 ;*---------------------------------------------------------------------*/
 (define prelude-lexer
    (let ((start-rule #f))
-      (regular-grammar ((letter (or #\_ (inside #\a #\z #\A #\Z)))
-			(digit  (inside #\0 #\9)))
+      (regular-grammar ((letter (or #\_ (uncase (in ("az")))))
+			(digit  (in ("09"))))
 
 	 ;; blank
 	 ((+ (in #\space #\newline))
 	  (ignore))
 
 	 ;; comment
-	 (("/*" (* (or (out #\*) (#\* (out #\/)))) #\* #\/)
+	 ((: "/*" (* (or (out #\*) (: #\* (out #\/)))) #\* #\/)
 	  (ignore))
 
 	 ;; token
-	 (("%token " (* (all)))
+	 ((: "%token " (* all))
 	  (let* ((string (substring (the-string) 7 (the-length)))
 		 (port   (open-input-string string)))
 	     (read/rp token-reader port)
 	     (ignore)))
 
 	 ;; start
-	 (("%start " (* (all)))
+	 ((: "%start " (* all))
 	  (let ((string (the-string))
 		(len    (the-length)))
 	     (set! start-rule (substring string 7 len))
 	     (ignore)))
       
 	 ;; %%
-	 (("%%")
+	 ("%%"
 	  start-rule)
 
 	 ;; else
 	 (else
 	  (error/location "yacc->bigloo"
 			  "Illegal char"
-			  (the-failing-char)
+			  (the-failure)
 			  (input-port-name input-port)
-			  (input-port-filepos input-port))))))
+			  (input-port-position input-port))))))
 
 ;*---------------------------------------------------------------------*/
 ;*    skip-semantics-action ...                                        */
@@ -245,79 +244,81 @@
       (regular-grammar ()
 	 
 	 ;; comment
-	 (("/*" (* (or (out #\*) (#\* (out #\/)))) #\* #\/)
+	 ((: "/*" (* (or (out #\*) (: #\* (out #\/)))) #\* #\/)
 	  (ignore))
 
 	 ;; string
-	 ((#\" (* (out #\")) #\")
+	 ((: #\" (* (out #\")) #\")
 	  (ignore))
 
-	 ((#\{)
+	 (#\{
 	  (set! nested (+fx nested 1))
 	  (ignore))
 	 
-	 ((#\})
+	 (#\}
 	  (set! nested (-fx nested 1))
 	  (if (>fx nested 0)
 	      (ignore)
-	      'done))
+	      (begin
+		 (set! nested 1)
+		 'done)))
 	 
 	 ((+ (out #\} #\/ #\" #\{))
 	  (ignore))
 
 	 (else
-	  (let ((c (the-failing-char)))
+	  (let ((c (the-failure)))
 	     (if (eof-object? c)
 		 (error/location "yacc->bigloo"
 				 "Illegal semantic action"
 				 c
 				 (input-port-name input-port)
-				 (input-port-filepos input-port))
+				 (input-port-position input-port))
 		 (ignore)))))))
 	 
 ;*---------------------------------------------------------------------*/
 ;*    lexer ...                                                        */
 ;*---------------------------------------------------------------------*/
 (define lexer
-   (regular-grammar ((letter (or #\_ (inside #\a #\z #\A #\Z)))
-		     (digit  (inside #\0 #\9)))
+   (regular-grammar ((letter (or #\_ (uncase (in ("az")))))
+		     (digit  (in ("09"))))
 
       ;; blank
       ((+ (in #\space #\newline #\tab))
        (ignore))
 
       ;; comment
-      (("/*" (* (or (out #\*) (#\* (out #\/)))) #\* #\/)
+      ((: "/*" (* (or (out #\*) (: #\* (out #\/)))) #\* #\/)
        (ignore))
 
       ;; semantics actions
-      ((#\{)
+      (#\{
        (read/rp skip-semantics-action input-port)
        (ignore))
       
       ;; stop
-      (("%%")
+      ("%%"
        'stop)
 
       ;; id
-      ((letter (* (or digit letter)))
+      ((: letter (* (or digit letter)))
        (list 'ID (the-string)))
 
       ;; :
-      ((#\:)
+      (#\:
        (list ':))
 
       ;; ;
-      ((#\;)
+      (#\;
        (list 'SEMI-COMMA))
 
       ;; |
-      ((#\|)
+      (#\|
        (list '|))
 
       ;; "???"
-      ((#\" (* (or #\" (out #\" #\Newline ))) #\")
-       (let* ((res   (the-small-string))
+      ((: #\" (* (or #\" (out #\" #\Newline ))) #\")
+       (let* ((res   (the-substring 1 (-fx (the-length) 1)))
 	      (token (cond
 			((string=? res "")
 			 'EMPTY-STRING)
@@ -327,8 +328,8 @@
 	  (list 'ID token)))
       
       ;; '???'
-      ((#\' (or "\\'" (+ (out #\' #\Newline ))) #\')
-       (let* ((res   (the-small-string))
+      ((: #\' (or "\\'" (+ (out #\' #\Newline ))) #\')
+       (let* ((res   (the-substring 1 (-fx (the-length) 1)))
 	      (token (cond
 			((string=? res "(")
 			 'PAR-OPEN)
@@ -356,9 +357,9 @@
       (else
        (error/location "yacc->bigloo"
 		       "Illegal char"
-		       (the-failing-char)
+		       (the-failure)
 		       (input-port-name input-port)
-		       (input-port-filepos input-port)))))
+		       (input-port-position input-port)))))
 
 ;*---------------------------------------------------------------------*/
 ;*    parser ...                                                       */
@@ -471,7 +472,12 @@
 						   fname
 						   pos))
 				  (else
-				   (error proc mes obj))))))
+				   (error/location
+				    proc
+				    mes
+				    obj
+				    (input-port-name *iport*)
+				    (input-port-position *iport*)))))))
 	     (output-tokens)
 	     (output-rules)
 	     (display ")" *oport*)))))
@@ -526,3 +532,4 @@
    (for-each (lambda (rule)
 		(fprint *oport* rule))
 	     (reverse! *rule*)))
+;</pre></font>
