@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
-;*    serrano/prgm/project/bigloo/recette/apply.scm ...                */
+;*    serrano/prgm/project/bigloo/recette/apply.scm                    */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Tue Nov  3 10:58:26 1992                          */
-;*    Last change :  Thu Jul 15 13:40:54 1993  (serrano)               */
+;*    Last change :  Wed Apr  1 14:05:31 1998 (serrano)                */
 ;*                                                                     */
 ;*    On test differentes sortes d'apply                               */
 ;*---------------------------------------------------------------------*/
@@ -48,8 +46,10 @@
 (module apply
    (import  (main "main.scm")
 	    (alias-aux "alias-aux.scm"))
+   (extern  (macro c-dummy::obj (::obj . ::obj) ""))
    (include "test.sch")
-   (export  (test-apply)))
+   (export  (test-apply)
+	    (apply-dummy x y)))
  
 ;*---------------------------------------------------------------------*/
 ;*    gtest1 ...                                                       */
@@ -129,11 +129,19 @@
 (define (extern-apply x)
    (apply foo1 x))
 
+;*---------------------------------------------------------------------*/
+;*    apply-dummy ...                                                  */
+;*    -------------------------------------------------------------    */
+;*    Bigloo1.9 was unable to compile this extern apply form.          */
+;*---------------------------------------------------------------------*/
+(define (apply-dummy x y)
+   (apply c-dummy (cons x y)))
+
 ;*---------------------------------------------------------------------*/
 ;*    test-apply ...                                                   */
 ;*---------------------------------------------------------------------*/
 (define (test-apply)
-   (test-module "apply" "apply.scm" #f)
+   (test-module "apply" "apply.scm")
    (test "extern apply" (extern-apply '(1)) 1)
    (test "gapply" (apply gtest1 '(1 3)) 4)
    (test "gapply" ((begin gtest1) 1 3) 4)
