@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
 ;*    serrano/prgm/project/bigloo/recette/bexit.scm                    */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Fri Jun 12 10:06:03 1992                          */
-;*    Last change :  Fri Mar 29 11:13:13 1996 (serrano)                */
+;*    Last change :  Mon Sep 21 16:40:20 1998 (serrano)                */
 ;*                                                                     */
 ;*    On test les trois sortes de `bind-exit'                          */
 ;*---------------------------------------------------------------------*/
@@ -106,23 +104,28 @@
 ;*---------------------------------------------------------------------*/
 (define bug-bexit-1
    (lambda (x1)
-      (labels ((:-d.try1015 (:-d.1008)
+      (labels ((!-d.try1015 (!-d.1008)
 			    (if :-d.1008
 				(bind-exit
-				 (:-d.staticexit1010)
+				 (!-d.staticexit1010)
 				 0)
 				0)))
-	 (:-d.try1015 0))))
+	 (!-d.try1015 0))))
 
 ;*---------------------------------------------------------------------*/
 ;*    test5 ...                                                        */
 ;*---------------------------------------------------------------------*/
 (define (test5 x)
-   (try (if (string? x)
-	    (test5 '(1 2 3))
-	    (car x))
-	(lambda (a b c d)
-	   (a #t))))
+   (let ((g 0))
+      (try (if (string? x)
+	       (test5 '(1 2 3))
+	       (car x))
+	   (lambda (a b c d)
+	      (if (=fx g 0)
+		  (begin
+		     (set! g (+fx g 1))
+		     (a #t))
+		  (a #f))))))
 
 ;*---------------------------------------------------------------------*/
 ;*    *escape* ...                                                     */
@@ -141,14 +144,20 @@
 ;*    test-bind-exit ...                                               */
 ;*---------------------------------------------------------------------*/
 (define (test-bind-exit)
-   (test-module "bind-exit" "bind-exit.scm" #t)
+   (test-module "bind-exit" "bind-exit.scm")
    (test "goto bind-exit" (test0 4) 5)
    (test "simple bind-exit" (test1 1 2 4) 7)
    (test "simple bind-exit" (test1 1 'toto 4) -1)
    (test "call-with-current-continuation" (test2 1 2 4) 7)
    (test "call-with-current-continuation" (test2 1 'toto 4) -1)
    (test "kapture bind-exit" (test4 (lambda (x y) x)) 1)
-   (test "try" (test5 5) #t)
+   (test "try" (begin
+		  (try (error 1 2 3) (lambda (a b c d) (a #t)))
+		  (try (test5 5)
+		       (lambda (a b c d)
+			  #f)))
+	 #t)
+   (test "try(next)" (try (error 1 2 3) (lambda (a b c d) (a #t))) #t)
    (test "cfa" (test6) 345)
    (test "unwind" (eval '(unwind-protect 10 10)) 10)
    (test "unwind" (eval '(bind-exit (exit) (unwind-protect (exit 10) 9))) 10)
