@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
 ;*    serrano/prgm/project/bigloo/recette/callcc.scm                   */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Tue Nov  3 13:57:49 1992                          */
-;*    Last change :  Wed Apr  3 14:37:59 1996 (serrano)                */
+;*    Last change :  Wed Jun  3 12:36:00 1998 (serrano)                */
 ;*                                                                     */
 ;*    On test differents call/cc                                       */
 ;*---------------------------------------------------------------------*/
@@ -48,7 +46,8 @@
 (module callcc
    (import  (main "main.scm"))
    (include "test.sch")
-   (export  (test-callcc)))
+   (export  (test-callcc)
+	    (plante-1)))
 
 ;*---------------------------------------------------------------------*/
 ;*    cons-gd ...                                                      */
@@ -57,6 +56,24 @@
    `(let ((a ,a))
        (cons a ,d)))
 
+;*---------------------------------------------------------------------*/
+;*    plante-1 ...                                                     */
+;*---------------------------------------------------------------------*/
+(define (plante-1)
+   (begin
+      (set-exit
+       (an-exit1013)
+       (let ()
+	  (push-exit! an-exit1013 #t)
+	  (let ((exp (let ((body1018 (lambda () 9)))
+			(set-exit
+			 (an-exit1025)
+			 (let ()
+			    (push-exit! an-exit1025 #f)
+			    (body1018))))))
+	     (set! exp #unspecified))))
+      9))
+   
 ;*---------------------------------------------------------------------*/
 ;*    qnc-plante ...                                                   */
 ;*---------------------------------------------------------------------*/
@@ -176,7 +193,7 @@
 ;*    test-callcc ...                                                  */
 ;*---------------------------------------------------------------------*/
 (define (test-callcc)
-   (test-module "callcc" "callcc.scm" #t)
+   (test-module "callcc" "callcc.scm")
    (test "call/cc(r4)" (call/cc (lambda (exit)
 				   (for-each (lambda (x)
 						(if (negative? x)
@@ -284,10 +301,9 @@
 		   (eval '(leaf-eq? '(a a) '(a b))))
 	 #f)
    (test "lambda-stack" (lambda-trace 1) 1)
-   (test "cell-ref" ((qnc-plante 4) 5) 10))
-
-
-		  
-   
-	    
-
+   (test "cell-ref" ((qnc-plante 4) 5) 10)
+   (test "call-with-values" (call-with-values (lambda ()
+						 (call/cc (lambda (cont)
+							     (cont 'x 'y))))
+					      cons)
+	 '(x . y)))
