@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*=====================================================================*/
-;*    serrano/prgm/project/bigloo/recette/cse.scm ...                  */
+;*    serrano/prgm/project/bigloo/recette/cse.scm                      */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Thu Apr 29 17:25:53 1993                          */
-;*    Last change :  Thu Apr 29 17:31:40 1993  (serrano)               */
+;*    Last change :  Wed Apr  1 14:06:24 1998 (serrano)                */
 ;*                                                                     */
 ;*    On test l'elimination de sous expression commune.                */
 ;*=====================================================================*/
@@ -68,11 +66,28 @@
       (let ((z (car x)))
 	 z)))
 
+;*---------------------------------------------------------------------*/
+;*    gee ...                                                          */
+;*---------------------------------------------------------------------*/
+(define (gee l::pair)
+   ;; this function was badly compiled due to a bug in the cse
+   ;; that propagate the binding (a (c-car l)) into the loop.
+   (let ((a (c-car l)))
+      (let loop ((a a))
+	 (if (c-pair? a)
+	     (begin
+		(c-set-car! l '(3))
+		(loop (c-cdr a)))
+	     (let ((a (c-car l)))
+		(c-set-cdr! a 4)
+		a))))) 
+
 ;*---------------------------------------------------------------------*/
 ;*    test-cse ...                                                     */
 ;*---------------------------------------------------------------------*/
 (define (test-cse)
-   (test-module "cse" "cse.scm" #f)
+   (test-module "cse" "cse.scm")
    (test "cse" (foo '(1 2)) 3)
-   (test "cse" (bar '(1 2)) 3))
+   (test "cse" (bar '(1 2)) 3)
+   (test "cse" (gee '((1))) '(3 . 4)))
 
