@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
 ;*    serrano/prgm/project/bigloo/recette/define.scm                   */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Thu Jan  7 16:20:22 1993                          */
-;*    Last change :  Fri Jul 21 17:48:51 1995 (serrano)                */
+;*    Last change :  Sun May 24 06:50:09 1998 (serrano)                */
 ;*                                                                     */
 ;*    On test les `define's internes                                   */
 ;*---------------------------------------------------------------------*/
@@ -70,11 +68,44 @@
 (define gee5 foo5)
 (set! foo5 (lambda (y) 9))
 
+(define-inline (foo6 x)
+   (define (foo-inner x)
+      x)
+   (foo-inner x))
+
+;*---------------------------------------------------------------------*/
+;*    typed inner define                                               */
+;*---------------------------------------------------------------------*/
+(define (typed-define y)
+   (define (inner::int x) x)
+   (inner y))
+
+;*---------------------------------------------------------------------*/
+;*    n-ary inner define                                               */
+;*---------------------------------------------------------------------*/
+(define (n-ary-define y)
+   (define (inner x . y) (cons x y))
+   (inner y y))
+
+;*---------------------------------------------------------------------*/
+;*    n-ary typed inner define                                         */
+;*---------------------------------------------------------------------*/
+(define (n-ary-typed-define y)
+   (define (inner::pair x . y) (cons x y))
+   (inner y y))
+
+;*---------------------------------------------------------------------*/
+;*    untyped inner define ...                                         */
+;*---------------------------------------------------------------------*/
+(define (set-derives)
+  (define dset  (make-vector 10 -1))
+  dset)
+
 ;*---------------------------------------------------------------------*/
 ;*    test-define ...                                                  */
 ;*---------------------------------------------------------------------*/
 (define (test-define)
-   (test-module "define" "define.scm" #f)
+   (test-module "define" "define.scm")
    (test "internal" (test1 1) 1)
    (test "internal" (test3 1) 1)
    (test "internal" (test4 1) 1)
@@ -94,7 +125,12 @@
    (test "alias" (gee3 5 6) 11)
    (test "alias" (gee4) 5)
    (test "alias" (gee5 5) 6)
-   (test "alias" (foo5 5) 9))
+   (test "alias" (foo5 5) 9)
+   (test "inline" (foo6 6) 6)
+   (test "inner"  (typed-define 5) 5)
+   (test "inner"  (n-ary-define 5) '(5 5))
+   (test "inner"  (n-ary-typed-define 5) '(5 5))
+   (test "inner"  (vector? (set-derives)) #t))
 
 ;*---------------------------------------------------------------------*/
 ;*    Une forme top-level                                              */
