@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
 ;*    serrano/prgm/project/bigloo/recette/flonum.scm                   */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Thu Nov 26 11:59:37 1992                          */
-;*    Last change :  Thu Mar 23 16:58:59 1995 (serrano)                */
+;*    Last change :  Wed Apr  1 14:07:07 1998 (serrano)                */
 ;*                                                                     */
 ;*    On test un peu les flotants (il le faut bien).                   */
 ;*---------------------------------------------------------------------*/
@@ -58,11 +56,17 @@
        1
        (* (fact (- x 1)) x)))
 
+;*---------------------------------------------------------------------*/
+;*    sqrt-test ...                                                    */
+;*---------------------------------------------------------------------*/
+(define (sqrt-test x::double)
+   (sqrt x))
+
 ;*---------------------------------------------------------------------*/
 ;*    test-flonum ...                                                  */
 ;*---------------------------------------------------------------------*/
 (define (test-flonum)
-   (test-module "flonum" "flonum.scm" #f)
+   (test-module "flonum" "flonum.scm")
    (test "flonum"   3.141592 3.141592)
    (test "flonum"   (/ (inexact->exact (cos 0)) 2) 0.5)
    (test "flonum"   (/ 1 2) 0.5)
@@ -85,5 +89,9 @@
    (test "ceiling"  (ceiling 3.5) 4.0)
    (test "truncate" (truncate 3.5) 3.0)
    (test "round"    (round 3.5) 4.0)
-   (test "atan"     (let ((r (atan 1.0 1.0))) (> r 0)) #t))
+   (test "sqrt"     (sqrt-test 4.0) 2.0)
+   (test "atan"     (let ((r (atan 1.0 1.0))) (> r 0)) #t)
+   (test "prec"     (let ((num (+ 1e-6 1e-12)))
+		       (=fl (string->number (number->string num)) num))
+	            #t))
 
