@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
 ;*    serrano/prgm/project/bigloo/recette/foreign.scm                  */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Tue May 19 15:38:42 1992                          */
-;*    Last change :  Thu Apr  4 10:42:32 1996 (serrano)                */
+;*    Last change :  Sat Apr 11 07:51:26 1998 (serrano)                */
 ;*                                                                     */
 ;*    Le fichier principale de test des foreign                        */
 ;*---------------------------------------------------------------------*/
@@ -45,11 +43,12 @@
 ;*---------------------------------------------------------------------*/
 ;*    Le module                                                        */
 ;*---------------------------------------------------------------------*/
-(module foreign
+(module rforeign
    (include "test.sch") 
    (import  (bis big-file "big-file.scm")
 	    (main "main.scm"))
    (export  (test-foreign))
+   (extern  (macro sprn::int (::string ::string . ::long) "sprintf"))
    (foreign (string hux (string) "hux")
             (int var "var")
 	    (include "c-file.h")
@@ -69,12 +68,11 @@
 	    (type p1 (array int) "int $[22]")
 	    
 	    (type s0 (struct (int key "key") (el* next "next")) "struct el")
-	    (type s1 s0 "EL")
+	    (type s1* s0* "EL *")
 	    
 	    (type pt (struct (int x "x") (int y "y")) "Point")
-	    (type pt-foo pt "Point")
-	    (type pt-foo-2 pt-foo "Point")
-	    (type pt-foo* (pointer pt-foo) "Point *")
+	    (type pt-foo* pt* "Point *")
+	    (type pt-foo-2* pt-foo* "Point *")
 	    (type pt-bar pt* "Point *")
 	    (type pt-bar* (pointer pt-bar) "Point **")
 	    
@@ -97,6 +95,18 @@
 (define (boo s)
    (hux s))
  
+;*---------------------------------------------------------------------*/
+;*    booboo                                                           */
+;*---------------------------------------------------------------------*/
+(define (booboo f)
+   0 1 2 3 4 5 6 7 8 9 0
+   0 1 2 3 4 5 6 7 8 9 0
+   0 1 2 3 4 5 6 7 8 9 0
+   0 1 2 3 4 5 6 7 8 9 0
+   0 1 2 3 4 5 6 7 8 9 0
+   0 1 2 3 4 5 6 7 8 9 0
+   (f  "toto n'est pas content"))
+ 
 ;*---------------------------------------------------------------------*/
 ;*    test-struct ...                                                  */
 ;*---------------------------------------------------------------------*/
@@ -135,9 +145,9 @@
 ;*---------------------------------------------------------------------*/
 (define (test-function)
    (define (a-test f)
-      (and (bfun? f)
+      (and (fun? f)
 	   (=fx (fun-call f 5) 9)
-	   (bfun2? f)
+	   (fun2? f)
 	   (=fx (fun2-call f 5) 9)))
    (and (a-test f1) (a-test f2)))
 
@@ -147,7 +157,7 @@
 (define (test-pointer)
    (define (a-test maker)
       (let ((p (maker)))
-	 (if (and (bp0? p) (bp1? p))
+	 (if (and (p0? p) (p1? p))
 	     (begin
 		(p0-set! p 0 -99)
 		(p1-set! p 1 99)
@@ -161,7 +171,7 @@
 (define (test-struct*)
    (let ((s0 (make-s0*))
 	 (s1 (make-s1*)))
-      (if (and (bs0? s0) (bs1? s0) (bs0? s1) (bs1? s1))
+      (if (and (s0*? s0) (s1*? s0) (s0*? s1) (s1*? s1))
 	  (begin
 	     (s0*-key-set! s0 4)
 	     (s0*-key-set! s1 -4)
@@ -209,11 +219,12 @@
 ;*    test-foreign ...                                                 */
 ;*---------------------------------------------------------------------*/
 (define (test-foreign)
-   (test-module "foreign" "foreign.scm" #f)
+   (test-module "foreign" "foreign.scm")
    (test "foreign"      var 9)
    (test "foreign"      (begin (set! var (+ 1 var)) var) 10)
    (test "foreign"      (foo 4) 5)
    (test "foreign"      (boo "toto n'est pas content") "TOTO EST CONTENT")
+   (test "closure"      (booboo hux) "TOTO EST CONTENT")
    (test "foreign"      (bis 5) 6)
    (test "struct"       (test-struct 5) (+ 0 1 2 3 4 5))
    (test "struct-ref"   (el*-key (define-el 5)) 5)
@@ -223,17 +234,23 @@
 				 0) 5)
    (test "array"        (inexact->exact (test-array 10)) 0)
    (test "eq?"          (=el* (make-dummy-el) (make-dummy-el)) #t)
-   (test "checker"      (bel? (make-el*)) #t)
-   (test "checker"      (bel? 7) #f)
-   (test "checker"      (lux bel? (make-el*)) #t)
-   (test "checker"      (lux bel? 7) #f)
+   (test "checker"      (el*? (make-el*)) #t)
+   (test "checker"      (el*? 7) #f)
+   (test "checker"      (lux el*? (make-el*)) #t)
+   (test "checker"      (lux el*? 7) #f)
    (test "function"     (test-function) #t)
    (test "pointer"      (test-pointer) #t)
    (test "struct*"      (test-struct*) #t)
    (test "alias"        (test-alias1) #t)
    (test "alias"        (test-alias2) #t)
    (test "alias"        (test-alias3) #t)
-   (test "struct array" (test-struct-array) 18))
+   (test "struct array" (test-struct-array) 18)
+   (test "n-ary"        (let ((m 10)
+			      (s (make-string 11)))
+			   (sprn s #"%d + 1 = %d" m (+fx 1 m))
+			   s)
+	 "10 + 1 = 11"))
+
 
 
 
