@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
-;*    serrano/prgm/project/bigloo/recette/globalis.scm                 */
+;*    /home/tahoe/serrano/prgm/project/bigloo/recette/globalis.scm     */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Tue Nov  3 11:30:18 1992                          */
-;*    Last change :  Mon Jul 10 10:14:14 1995 (serrano)                */
+;*    Last change :  Tue Oct 27 08:11:58 1998 ()                       */
 ;*                                                                     */
 ;*    Des tests qui globalisent des fonctions locales par la passe Glo */
 ;*---------------------------------------------------------------------*/
@@ -52,10 +50,14 @@
 	    (plante-2 x)
 	    (plante-3 x)
 	    (plante-4 x)
+	    (_plante-4 x y)
 	    (plante-k2 l)
 	    (compile x)
 	    (plante-5 x)
-	    (plante-6 x e)))
+	    (plante-6 x e)
+	    (plante-7)
+	    (plante-8))
+   (option  (set! *inlining?* #f)))
 
 ;*---------------------------------------------------------------------*/
 ;*    test1 ...                                                        */
@@ -70,8 +72,8 @@
 ;*    test2 ...                                                        */
 ;*---------------------------------------------------------------------*/
 (define (test2 x y z)
-   (labels ((hux (a)  x)
-	    (bar (a) (hux y))
+   (labels ((hux (a1)  x)
+	    (bar (a1) (hux y))
 	    (gee ()  (bar z)))
       gee))
 
@@ -106,9 +108,9 @@
 ;*    test6                                                            */
 ;*---------------------------------------------------------------------*/
 (define (test6 . c)
-   (let ((a 0)
+   (let ((a2 0)
 	 (b 0))
-      (labels ((foo (x) (set! a x) a)
+      (labels ((foo (x) (set! a2 x) a2)
 	       (bar (y) (set! b y) (foo b)))
 	 (bar 1)
 	 foo)))
@@ -117,7 +119,7 @@
 ;*    test7 ...                                                        */
 ;*---------------------------------------------------------------------*/
 (define (test7 x)
-   (labels ((bar (a) (hux a))
+   (labels ((bar (a3) (hux a3))
 	    (gee (b) bar)
 	    (hux (c) x))
       bar
@@ -171,6 +173,12 @@
 	    (foo (x) x))
       (hux foo)))
 
+;*---------------------------------------------------------------------*/
+;*    _plante-4 ...                                                    */
+;*---------------------------------------------------------------------*/
+(define (_plante-4 x y)
+   (+ x y))
+
 ;*---------------------------------------------------------------------*/
 ;*    Un prgm qui ne se compilait pas convenablement.                  */
 ;*---------------------------------------------------------------------*/
@@ -241,9 +249,9 @@
 ;*    encore une fonction qui ne se compilait pas.                     */
 ;*---------------------------------------------------------------------*/
 (define plante-5
-   (lambda (a)
+   (lambda (a4)
       (letrec ((x3 (lambda (x4)
-		      (a 0)
+		      (a4 0)
 		      (lambda (c)
 			 (labels ((foo () (lambda (x9) (x3 0))))
 			    (foo))))))
@@ -259,18 +267,80 @@
 		     (foo) x)))
       (loop)))
 
+;*---------------------------------------------------------------------*/
+;*    plante-7 ...                                                     */
+;*---------------------------------------------------------------------*/
+(define (plante-7)
+   (begin
+      (set-exit
+       (an-exit1013)
+       (let ()
+	  (push-exit! an-exit1013 #t)
+	  (let ((exp (let ((body1018 (lambda () 9)))
+			(set-exit
+			 (an-exit1025)
+			 (let ()
+			    (push-exit! an-exit1025 #f)
+			    (body1018))))))
+	     (set! exp #unspecified)
+	     (labels ((foo () (print exp)))
+		(plante-7-bar foo)))))
+      9))
+
+(define (plante-7-bar f)
+   (print (f)))
+
+;*---------------------------------------------------------------------*/
+;*    plante-8 ...                                                     */
+;*---------------------------------------------------------------------*/
+(define (plante-8)
+   (let ((exp (let ((handler1018
+		     (lambda (escape proc obj msg)
+			9)))
+		 (set-exit
+		  (an-exit1019)
+		  (dynamic-wind
+		     (lambda ()
+			(add-error-handler! handler1018 #f))
+		     (lambda () #f)
+		     (lambda () #f))))))
+      (set-exit
+       (an-exit1025)
+       (dynamic-wind
+	  (lambda ()
+	     (add-error-handler! #f #f))
+	  (lambda ()
+	     (eval exp))
+	  (lambda () #f)))
+      (set! exp #unspecified)))
+
+;*---------------------------------------------------------------------*/
+;*    test8 ...                                                        */
+;*---------------------------------------------------------------------*/
+(define (test8 str)
+   (let ((g (regular-grammar ()
+	       (#\)
+		'())
+	       (#\(
+		(let* ((car (ignore))
+		       (cdr (ignore)))
+		   (cons car cdr)))
+	       ((+ (out #\( #\)))
+		(the-symbol))))
+	 (p (open-input-string str)))
+      (read/rp g p)))
+
 ;*---------------------------------------------------------------------*/
 ;*    test-globalisation ...                                           */
 ;*---------------------------------------------------------------------*/
 (define (test-globalisation)
-   (test-module "globalisation" "globalisation.scm" #f)
+   (test-module "globalisation" "globalisation.scm")
    (test "globalisation" ((test1)) 0)
    (test "kapture" ((test2 1 2 3)) 1)
    (test "kapture" (test3) 1)
    (test "cell" ((test4 1 2) 3) 2)
    (test "cell" ((test5 1 2 3 4) 2) 2)
    (test "cell" ((test6 1 2 3 4) 2) 2)
-   (test "globalisation" (((test7 5) 6) 7) 5))
-
-
-   
+   (test "globalisation" (((test7 5) 6) 7) 5)
+   (test "rgc" (test8 "(foo(bar(gee)))") '(foo bar gee))
+   (test "_" (_plante-4 5 6) 11))
