@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
 ;*    serrano/prgm/project/bigloo/recette/inline.scm                   */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Fri Nov  6 10:40:50 1992                          */
-;*    Last change :  Mon Jan 22 18:58:36 1996 (serrano)                */
+;*    Last change :  Wed Apr  1 14:08:53 1998 (serrano)                */
 ;*                                                                     */
 ;*    Des petits tests qui verifie que l'inlining se fait              */
 ;*    convenablement.                                                  */
@@ -50,7 +48,10 @@
    (import  (main "main.scm"))
    (include "test.sch")
    (export  (test-inline)
-	    (link-with x)))
+	    (link-with x)
+	    (gee-inline a b c d e f)
+	    (foo-inline x)
+	    (type-hux x)))
 
 ;*---------------------------------------------------------------------*/
 ;*    link-with ...                                                    */
@@ -114,12 +115,37 @@
        'done
        (loop2 (-fx n 1) s1 s2 (equal? s1 s2))))
 
+;*---------------------------------------------------------------------*/
+;*    Inline of exported recursive functions                           */
+;*---------------------------------------------------------------------*/
+(define (gee-inline a b c d e f)
+   (gee-inline a b c d e f))
+
+(define (foo-inline x)
+   (gee-inline 1 2 3 4 5 6)
+   (gee-inline 1 2 3 4 5 6))
+
+;*---------------------------------------------------------------------*/
+;*    Type result                                                      */
+;*---------------------------------------------------------------------*/
+(define (type-hux x) x)
+
+(define-inline (type-foo::char x)
+   (type-hux x))
+
+(define (type-gee x)
+   ;; the inlining of (foo x) must produce a type error
+   (try (type-foo x)
+	(lambda (a b c d)
+	   (a (+fx x 1)))))
+
 ;*---------------------------------------------------------------------*/
 ;*    test-inline ...                                                  */
 ;*---------------------------------------------------------------------*/
 (define (test-inline)
-   (test-module "inline" "inline.scm" #f)
+   (test-module "inline" "inline.scm")
    (test "inline" ((foo 1) '(1 2 3 4)) 2)
    (test "type-rq" (hux) 2)
    (test "loop" (loop 2 2) '((2)))
-   (test "loop" (loop2 10 2 2 #f) 'done))
+   (test "loop" (loop2 10 2 2 #f) 'done)
+   (test "type" (type-gee 4) 5))
