@@ -1,49 +1,47 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
-;*---------------------------------------------------------------------*/
-
-
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
+;*=====================================================================*/
 ;*    serrano/prgm/project/bigloo/recette/main.scm                     */
-;*                                                                     */
+;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Mon Nov  2 17:24:13 1992                          */
-;*    Last change :  Fri Mar 29 11:13:34 1996 (serrano)                */
-;*                                                                     */
-;*    Le point d'entree de la recette                                  */
-;*---------------------------------------------------------------------*/
+;*    Last change :  Mon Sep 21 09:35:47 1998 (serrano)                */
+;*    -------------------------------------------------------------    */
+;*    The recette entry point                                          */
+;*=====================================================================*/
 
 ;*---------------------------------------------------------------------*/
-;*    Le module                                                        */
+;*    The module                                                       */
 ;*---------------------------------------------------------------------*/
 (module main
    
@@ -64,6 +62,7 @@
 	   (vararity      "vararity.scm")
 	   (apply         "apply.scm")
 	   (globalisation "globalis.scm")
+	   (glo_cell      "cell.scm")
 	   (kapture       "kapture.scm")
 	   (filtre        "filtre.scm")
 	   (match         "match.scm")
@@ -76,10 +75,10 @@
 	   (callcc        "callcc.scm")
 	   (fringe        "fringe.scm")
 	   (tail          "tail.scm")
-	   (foreign       "foreign.scm")
+	   (rforeign      "foreign.scm")
 	   (big-file      "big-file.scm")
 	   (sqic          "sqic.scm")
-	   (eval          "eval.scm")
+	   (reval         "eval.scm")
 	   (inline        "inline.scm")
 	   (letrec        "letrec.scm")
 	   (macro         "macro.scm")
@@ -90,15 +89,23 @@
 	   (error         "error.scm")
 	   (include       "include.scm")
 	   (0cfa          "0cfa.scm")
+	   (sua           "sua.scm")
 	   (alias         "alias.scm")
 	   (alias-aux     "alias-aux.scm")
 	   (module        "module.scm")
 	   (import1       "import1.scm")
-	   (import2       "import2.scm"))
+	   (import2       "import2.scm")
+	   (object        "object.scm")
+	   (hygien        "hygien.scm")
+	   (wind          "wind.scm")
+	   (dsssl         "dsssl.scm")
+	   )
    
    (export (do-test name thunk good?)
-	   (test-module name file stop)
-	   *recette-port*))
+	   (test-module name file)
+	   *recette-port*)
+
+   (option (set! *debug* #f)))
    
 ;*---------------------------------------------------------------------*/
 ;*    Des variables statiques                                          */
@@ -110,7 +117,6 @@
 (define *verbose*       #f)
 (define *silent*        #t)
 (define *recette-port*  #f)
-(define *stop-on-error* #f)
 (define *tick-number*   -1)
 
 ;*---------------------------------------------------------------------*/
@@ -148,38 +154,36 @@
 	  (and (flonum? result)
 	       (flonum? wanted)
 	       (<fl (absfl (-fl result wanted)) 0.00001))))
-   (let ((result (thunk)))
-      (if (correct? result wanted)
-	  (begin
-	     (if (not *silent*)
-		 (begin
-		    (display* *test-number* #\. *module-name* " : "
-			      name " --> ")
-		    (display "ok.")))
-	     (if *verbose*
-		 (print " [" result "]")
-		 (if (not *silent*)
-		     (newline))))
-	  (begin
-	     (set! *nb-err* (+ 1 *nb-err*))
-	     (display* *test-number* #\. *module-name* " : " name )
-	     (if *stop-on-error*
-		 (error name
-			  (list "provided: " result)
-			  (list "wanted: " wanted))
-		 (begin
-		    (notify-error name (list "provided: " result)
-				  (list "wanted: " wanted))
-		    (if (not *silent*)
-			(print "not ok."))))))))
+   (try (let ((result (thunk)))
+	   (if (correct? result wanted)
+	       (begin
+		  (if (not *silent*)
+		      (begin
+			 (display* *test-number* #\. *module-name* " : "
+				   name " --> ")
+			 (display "ok.")))
+		  (if *verbose*
+		      (print " [" result "]")
+		      (if (not *silent*)
+			  (newline))))
+	       (begin
+		  (set! *nb-err* (+ 1 *nb-err*))
+		  (display* *test-number* #\. *module-name* " : " name )
+		  (error name
+			 (list "provided: " result)
+			 (list "wanted: " wanted)))))
+	(lambda (escape proc obj msg)
+	   (flush-output-port (current-output-port))
+	   (notify-error proc obj msg)
+	   (flush-output-port (current-error-port))
+	   (escape #f))))
 
 ;*---------------------------------------------------------------------*/
 ;*    test-module ...                                                  */
 ;*---------------------------------------------------------------------*/
-(define (test-module module-name file-name stop?)
+(define (test-module module-name file-name)
    (set! *module-name* module-name)
    (set! *test-number* 0)
-   (set! *stop-on-error* stop?)
    (if (not *silent*)
        (newline))
    (print file-name ":"))
@@ -211,6 +215,7 @@
        (error "recette-port" "Can't open output-file" "recette.log"))
    (try (begin
 	   (test-vital)
+	   (test-cell)
 	   (test-modulel)
 	   (test-hash)
 	   (test-bool)
@@ -225,12 +230,13 @@
 	   (test-kwote)
 	   (test-case)
 	   (test-bind-exit)
-	   (test-vararity) 
+	   (test-vararity)
 	   (test-apply)
 	   (test-globalisation)
 	   (test-kapture)
 	   (test-filtre)
 	   (test-match)
+	   (test-rgc)
 	   (test-rgc-trap)
 	   (test-rgc-jm)
 	   (test-rgc-eval)
@@ -238,6 +244,8 @@
 	   (test-read)
 	   (test-callcc)
 	   (test-fringe)
+	   (test-wind)
+	   (test-dsssl)
 	   (test-tail)
 	   (test-foreign)
 	   (test-sqic)
@@ -250,7 +258,11 @@
 	   (test-error)
 	   (test-include)
 	   (test-0cfa)
-	   (test-alias))
+	   (test-sua)
+	   (test-alias)
+	   (test-object)
+	   (test-hygien)
+	   )
 	(lambda (escape proc mes obj)
 	   (notify-error proc mes obj)
 	   (set! *nb-err* (+ 1 *nb-err*))
