@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
-;*    serrano/prgm/project/bigloo/recette/match.scm ...                */
+;*    serrano/prgm/project/bigloo/recette/match.scm                    */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Wed Jun 10 16:37:46 1992                          */
-;*    Last change :  Tue Jun 14 13:41:51 1994 (serrano)                */
+;*    Last change :  Wed Apr  1 14:09:22 1998 (serrano)                */
 ;*                                                                     */
 ;*    Un essai de match-case                                           */
 ;*---------------------------------------------------------------------*/
@@ -154,7 +152,7 @@
 ;*    test-match ...                                                   */
 ;*---------------------------------------------------------------------*/
 (define (test-match)
-   (test-module "match" "match.scm" #f)
+   (test-module "match" "match.scm")
    (test "let" (match-test) 'ok)
    (test "expand-define" (match-test-2 '(define (foo x) x)) 'do-define-lambda)
    (test "expand-define" (match-test-2 '(define foo (lambda (x) x)))
@@ -170,5 +168,6 @@
    (test "atom" (match-test-5 (make-s)) 'atom)
    (test "structure" (is-in-circle? 10 p-int) #t)
    (test "structure" (is-in-circle? 10 p-real) #t)
-   (test "structure" (begin (match-lambda (#{int-point} 'toto)) #t) #t))
+   (test "structure" (begin (match-lambda (#{int-point} 'toto)) #t) #t)
+   (test "??- vs trigraph" (pair? (expand '(match-case x ((??- . ?x) 1)))) #t))
 	
