@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
 ;*    serrano/prgm/project/bigloo/recette/number.scm                   */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Sat Nov 28 10:52:56 1992                          */
-;*    Last change :  Tue Mar 21 11:37:11 1995 (serrano)                */
+;*    Last change :  Wed Apr  1 14:09:46 1998 (serrano)                */
 ;*                                                                     */
 ;*    On test les operateurs generiques sur les nombres                */
 ;*---------------------------------------------------------------------*/
@@ -54,7 +52,7 @@
 ;*    test-number ...                                                  */
 ;*---------------------------------------------------------------------*/
 (define (test-number)
-   (test-module "number" "number.scm" #f)
+   (test-module "number" "number.scm")
    (test "=" (= 1 1) #t)
    (test "=" (= 1 1 1) #t)
    (test "=" (= 1 2 1) #f)
@@ -85,6 +83,7 @@
    (test "-" (let ((x 4.0)) (- x)) -4.0)
    (test "*" (* 1 2 3 4) 24)
    (test "/" (/ 12 3 2 1) 2)
+   (test "/" (/ (/ 4)) 4.0)
    (test "/fx" (/fx 5 4) 1)
    (test "/fx" (integer? (/fx 5 4)) #t)
    (test "zero?" (zero? 3) #f)
@@ -158,7 +157,8 @@
    (let ((x 3.1) (y 4))
       (test "flofix.>=" (>= 3.1 4) #f))
    (let ((x -0.2) (y 0))
-      (test "flofix.<" (< x y) #t)))
+      (test "flofix.<" (< x y) #t))
+   (test "string->number" (string->number "7F" 16) 127))
    
    
    
