@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
-;*    serrano/prgm/project/bigloo/recette/port.scm ...                 */
+;*    serrano/prgm/project/bigloo/recette/port.scm                     */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Sun May 24 10:56:01 1992                          */
-;*    Last change :  Wed Jan 18 17:16:40 1995 (serrano)                */
+;*    Last change :  Thu Oct 22 09:15:01 1998 (serrano)                */
 ;*                                                                     */
 ;*    On test les operations simples sur les ports                     */
 ;*---------------------------------------------------------------------*/
@@ -115,7 +113,7 @@
 ;*    test-input-port ...                                              */
 ;*---------------------------------------------------------------------*/
 (define (test-input-port)
-   (test-module "test-input-port" "port.scm" #f)
+   (test-module "test-input-port" "port.scm")
    (test "input" (open-input-file "wrong") (input-port? #\space))
    (test "input" (call-with-input-file "misc/input.txt" test1) #\.)
    (test "input" (test2 "misc/input.txt" 10) #\.)
@@ -126,4 +124,17 @@
       (test "char" (close-output-port p) "#a012"))
    (let ((p (open-output-string)))
       (write #a179 p)
-      (test "char" (close-output-port p) "#a179")))
+      (test "char" (close-output-port p) "#a179"))
+   (let* ((stringa (make-string 1020 #\a))
+	  (stringb (make-string 1020 #\b))
+	  (stringc (make-string 1020 #\c))
+	  (stringd (make-string 234 #\d))
+	  (string  (string-append stringa stringb stringc stringd))
+	  (port    (open-output-string))
+	  (res     (begin (display string port) (close-output-port port))))
+      (test "long write" res string))
+   (let ((p (open-output-string)))
+      (close-output-port p)
+      (test "close port"
+	    (try (write "stupid" p) (lambda (a b c d) (a #t)))
+	    #t)))
