@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
-;*    serrano/prgm/project/bigloo/recette/read.scm ...                 */
+;*    serrano/prgm/project/bigloo/recette/read.scm                     */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Fri May 22 16:17:03 1992                          */
-;*    Last change :  Mon Jan 10 10:15:08 1994 (serrano)                */
+;*    Last change :  Fri Sep 18 18:24:19 1998 (serrano)                */
 ;*                                                                     */
 ;*    Un essai de reader                                               */
 ;*---------------------------------------------------------------------*/
@@ -81,25 +79,13 @@
 		(loop (read port)
 		      (+ 1 n)))))))
 
-;*---------------------------------------------------------------------*/
-;*    read-string-test ...                                             */
-;*---------------------------------------------------------------------*/
-(define (read-string-test s)
-   (let* ((p   (open-input-string s))
-	  (l   (read-string p 5))
-	  (r   (read-string p 5))
-	  (res (string-append l r)))
-      (close-input-port p)
-      res))
-
 ;*---------------------------------------------------------------------*/
 ;*    test-read ...                                                    */
 ;*---------------------------------------------------------------------*/
 (define (test-read)
-   (test-module "read" "read.scm" #f)
+   (test-module "read" "read.scm")
    (test "test" (call-with-input-file "misc/input.txt" read-test)
 	 '(16 2 2 5 2 6 33))
-   (test "read" (cdr '((foo . bar) . hux)) 'hux)
-   (test "read-string" (read-string-test "0123456789") "0123456789"))
+   (test "read" (cdr '((foo . bar) . hux)) 'hux))
 		   
 
