@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
-;*    serrano/prgm/project/bigloo/recette/rgc-trap.scm ...             */
+;*    serrano/prgm/project/bigloo/recette/rgc-trap.scm                 */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Sun May 24 14:24:02 1992                          */
-;*    Last change :  Fri Nov 27 17:59:45 1992  (serrano)               */
+;*    Last change :  Mon Sep 21 14:14:27 1998 (serrano)                */
 ;*                                                                     */
 ;*    Un essai de grammaire qui trappe                                 */
 ;*---------------------------------------------------------------------*/
@@ -58,21 +56,21 @@
 	 (ntiti         0)
 	 (neol          0)
 	 (nbol          0)
-	 (neof          0)
+	 (neof          0) 
 	 (n             0))
-      (let ((grammar (regular-grammar ((lettre  (>-< #\a #\z)))
+      (let ((grammar (regular-grammar ((lettre  (in ("az"))))
 			((+ (in #\space #\newline))
 			 (set! n (+ (the-length) n))
 			 (ignore))
-			(titi ("titi")
-			      (context)
-			      (set! n (+ (the-length) n))
-			      (set! ncontext (+ 1 ncontext))
-			      (ignore))
-			(("titi")
+			((when (rgc-context? 'titi) "titi")
+			 (rgc-context)
+			 (set! n (+ (the-length) n))
+			 (set! ncontext (+ 1 ncontext))
+			 (ignore))
+			("titi"
 			 (set! ntiti (+ 1 ntiti))
 			 (set! n (+ (the-length) n)) 
-			 (context 'titi)
+			 (rgc-context 'titi)
 			 (ignore))
 			((eof "toto")
 			 (set! n (+ (the-length) n))
@@ -85,12 +83,14 @@
 			((bol "toto")
 			 (set! nbol (+ 1 nbol))
 			 (ignore))
-			(("toto")
+			("toto"
 			 (set! n (+ (the-length) n)) 
 			 (ignore))
 			((+ lettre)
 			 (set! n (+ (the-length) n)) 
-			 (ignore)))))
+			 (ignore))
+			(else
+			 (the-failure)))))
 	 (labels ((foo (port)
 		       (let loop ((r (read/rp grammar port)))
 			  (if (eof-object? r)
@@ -102,5 +102,5 @@
 ;*    test-rgc-trap ...                                                */
 ;*---------------------------------------------------------------------*/
 (define (test-rgc-trap)
-   (test-module "rgc-trap" "rgc-trap.scm" #f)
+   (test-module "rgc-trap" "rgc-trap.scm")
    (test "test" (rgc-test) '(3 3 3 3 1 66)))
