@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
 ;*    serrano/prgm/project/bigloo/recette/sqic.scm                     */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Tue Nov  3 14:27:18 1992                          */
-;*    Last change :  Wed Jan 24 10:35:00 1996 (serrano)                */
+;*    Last change :  Mon Sep 21 16:42:14 1998 (serrano)                */
 ;*                                                                     */
 ;*    On fait quelque tests qui portent sur la phase sqic->c.          */
 ;*---------------------------------------------------------------------*/
@@ -229,25 +227,25 @@
 (define filter@types
    (lambda (x1)
       (labels
-	    ((:-d.staticfail1024 () 9))
+	    ((!-d.staticfail1024 () 9))
 	 (case x1
 	    ((2)
 	     (case x1
 		((2)
 		 4)
-		(else (:-d.staticfail1024))))
+		(else (!-d.staticfail1024))))
 	    ((3)
 	     (case x1
 		((3)
 		 x1)
-		(else (:-d.staticfail1024))))
+		(else (!-d.staticfail1024))))
 	    (else
 	     (case x1
 		((4)
 		 (if x1
 		     (filter_list@types 4)
 		     8))
-		(else (:-d.staticfail1024))))))))
+		(else (!-d.staticfail1024))))))))
 
 ;*---------------------------------------------------------------------*/
 ;*    Un autre programme qui plantait `integ'                          */
@@ -260,24 +258,24 @@
 (define 2-171-concat_228@baltree
    (lambda (x1 x2)
       (labels
-	    ((:-d.staticfail1016
+	    ((!-d.staticfail1016
 	      ()
 	      0))
 	 (labels
-	       ((:-d.staticfail1017
+	       ((!-d.staticfail1017
 		 ()
 		 (labels
-		       ((:-d.staticfail1018
+		       ((!-d.staticfail1018
 			 ()
 			 (case x1
 			    ((2)
 			     (case x2
 				((2)
 				 (((join_132@baltree 0) 0) 0))
-				(else (:-d.staticfail1016))))
-			    (else (:-d.staticfail1016)))))
-		    (:-d.staticfail1018))))
-	    (:-d.staticfail1017)))))
+				(else (!-d.staticfail1016))))
+			    (else (!-d.staticfail1016)))))
+		    (!-d.staticfail1018))))
+	    (!-d.staticfail1017)))))
 
 
 ;*---------------------------------------------------------------------*/
@@ -288,7 +286,7 @@
    (letrec ((x1
 	     (lambda (x2)
 		(lambda (x3)
-		   (labels ((hux (:-d.1059) ((x1 x2) x3)))
+		   (labels ((hux (!-d.1059) ((x1 x2) x3)))
 		      (hux 0)
 		      0)))))
       (x1 '())))
@@ -320,7 +318,7 @@
 ;*    test-sqic ...                                                    */
 ;*---------------------------------------------------------------------*/
 (define (test-sqic)
-   (test-module "sqic" "sqic.scm" #f)
+   (test-module "sqic" "sqic.scm")
    (test "sqic" (foo '(1 2 3)) 3)
    (test "sqic" (bar 1) 4)
    (test "sqic" (side) 2))
