@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
 ;*    serrano/prgm/project/bigloo/recette/string.scm                   */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Tue Nov  3 10:18:56 1992                          */
-;*    Last change :  Wed Aug 30 10:05:32 1995 (serrano)                */
+;*    Last change :  Wed Jul  1 14:06:20 1998 (serrano)                */
 ;*                                                                     */
 ;*    On test differentes operations sur les chaines de characteres    */
 ;*---------------------------------------------------------------------*/
@@ -108,11 +106,47 @@
       (else
        (string-append "_n_o_f_u_c_k_i_n_g___init_or_fini" string))))
 
+;*---------------------------------------------------------------------*/
+;*    8bits->7bits ...                                                 */
+;*---------------------------------------------------------------------*/
+(define (8bits->7bits string::bstring)
+   (let ((len (string-length string)))
+      (let loop ((i 0))
+         (if (=fx i len)
+             string
+             (begin 
+                (case (string-ref string i)
+                   ((#\ #\)
+                    (string-set! string i #\e))
+                   ((#\ #\)
+                    (string-set! string i #\E))
+                   ((#\)
+                    (string-set! string i #\a))
+                   ((#\)
+                    (string-set! string i #\A))
+                   ((#\ #\)
+                    (string-set! string i #\u))
+                   ((#\ #\)
+                    (string-set! string i #\U))
+                   ((#\ #\)
+                    (string-set! string i #\i))
+                   ((#\ #\)
+                    (string-set! string i #\I))
+                   ((#\ #\)
+                    (string-set! string i #\o))
+                   ((#\ #\)
+                    (string-set! string i #\O))
+                   ((#\)
+                    (string-set! string i #\c))
+                   ((#\C)
+                    (string-set! string i #\C)))
+                (loop (+fx i 1)))))))
+
 ;*---------------------------------------------------------------------*/
 ;*    test-string ...                                                  */
 ;*---------------------------------------------------------------------*/
 (define (test-string)
-   (test-module "string" "string.scm" #f)
+   (test-module "string" "string.scm")
    (test "string=?" (string=? "toto n'est pas content"
 			      "toto n'est pas content")
 	 #t)
@@ -139,6 +173,8 @@
 	 "1123456789")
    (test "list->string" (list->string '(#\t #\o #\t #\o)) "toto")
    (test "string->list" (string->list "toto") '(#\t #\o #\t #\o))
+   (test "string->list" (string->list "-$>$") '(#\- #\$ #\> #\$))
+   (test "string->string" (list->string (string->list "tot oto")) "tot oto")
    (test "string->integer" (string->integer "01234") 1234)
    (test "integer->string" (integer->string 1234) "1234")
    (test "string->real" (string->real "1234.25") 1234.25)
@@ -161,6 +197,18 @@
    (test "string-ci>?" (string-ci>? "abcdef" "ABCDEG") #f)
    (test "string-ci>=?" (string-ci>=? "abcdef" "ABCDEG") #f)
    (test "string-ci>=?" (string-ci>=? "abcdef" "ABCDEF") #t)
+   (test "string-ci=?" (string-ci=? "toto" "titi") #f)
+   (test "string-ci=?" (string-ci=? "toto" "Toto") #t)
+   (test "string-ci=?" (string-ci=? "toto" "tot") #f)
+   (test "8bits" (8bits->7bits "") "EeEeIi")
+   (test "8bits-string<?" (string<? "abecd" "abcd") #t)
+   (test "8bits-string<=?" (string<=? "abecd" "abcd") #t)
+   (test "8bits-string>?" (string>? "abcd" "abecd") #t)
+   (test "8bits-string>=?" (string>=? "abcd" "abecd") #t)
+   (test "8bits-string-ci<?" (string-ci<? "abecd" "abcd") #t)
+   (test "8bits-string-ci<=?" (string-ci<=? "abecd" "abcd") #t)
+   (test "8bits-string-ci>?" (string-ci>? "abcd" "abecd") #t)
+   (test "8bits-string-ci>=?" (string-ci>=? "abcd" "abecd") #t)
    (test "foreign" (let ((x "\n\t\\\"")) (string->list x)) '(#\n #\t #\\ #\"))
    (test "foreign" (let ((x #"\n\\\"")) (string->list x))
 	 '(#\newline #\\ #\"))
@@ -172,10 +220,17 @@
    (test "escape" (string-length #"\000") 1)
    (test "escape" (char->integer (string-ref #"\000" 0)) 0)
    (test "escape" (char->integer (string-ref #"\003" 0)) 3)
+   (test "escape(8bits)" (list "big") '("big"))
    (test "id"
 	 (scheme-id->c-id "INITIALIZE-IMPORTED-MODULES!_FOO")
-	 "initialize_imported_modules__foo_7"))
+	 "initialize_imported_modules__foo_7")
+   (test "trigraph" "??-" (string-append "?" "?" "-"))
+   (test "suffix" (suffix "toto.scm") "scm")
+   (test "suffix" (suffix "toto") "")
+   (test "suffix" (suffix "./toto") "")
+   (test "suffix" (suffix "../toto") "")
+   (test "suffix" (suffix "/etc/rc.d/rc.3/K70syslogd") ""))
+
    
 
-
 	 
