@@ -1,43 +1,41 @@
 ;*---------------------------------------------------------------------*/
-;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
+;*   A pratical implementation for the Scheme programming language     */
 ;*                                                                     */
-;*                                     ,--^,                           */
-;*                               _ ___/ /|/                            */
-;*                           ,;'( )__, ) '                             */
-;*                          ;;  //   L__.                              */
-;*                          '   \    /  '                              */
-;*                               ^   ^                                 */
+;*                                    ,--^,                            */
+;*                              _ ___/ /|/                             */
+;*                          ,;'( )__, ) '                              */
+;*                         ;;  //   L__.                               */
+;*                         '   \\   /  '                               */
+;*                              ^   ^                                  */
 ;*                                                                     */
+;*   Copyright (c) 1992-1999 Manuel Serrano                            */
 ;*                                                                     */
-;*    This program is distributed in the hope that it will be useful.  */
-;*    Use and copying of this software and preparation of derivative   */
-;*    works based upon this software are permitted, so long as the     */
-;*    following conditions are met:                                    */
-;*           o credit to the authors is acknowledged following         */
-;*             current academic behaviour                              */
-;*           o no fees or compensation are charged for use, copies,    */
-;*             or access to this software                              */
-;*           o this copyright notice is included intact.               */
-;*      This software is made available AS IS, and no warranty is made */
-;*      about the software or its performance.                         */
+;*     Bug descriptions, use reports, comments or suggestions are      */
+;*     welcome. Send them to                                           */
+;*       bigloo-request@kaolin.unice.fr                                */
+;*       http://kaolin.unice.fr/bigloo                                 */
 ;*                                                                     */
-;*      Bug descriptions, use reports, comments or suggestions are     */
-;*      welcome Send them to                                           */
-;*        <Manuel.Serrano@inria.fr>                                    */
-;*        Manuel Serrano                                               */
-;*        INRIA -- Rocquencourt                                        */
-;*        Domaine de Voluceau, BP 105                                  */
-;*        78153 Le Chesnay Cedex                                       */
-;*        France                                                       */
+;*   This program is free software; you can redistribute it            */
+;*   and/or modify it under the terms of the GNU General Public        */
+;*   License as published by the Free Software Foundation; either      */
+;*   version 2 of the License, or (at your option) any later version.  */
+;*                                                                     */
+;*   This program is distributed in the hope that it will be useful,   */
+;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
+;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
+;*   GNU General Public License for more details.                      */
+;*                                                                     */
+;*   You should have received a copy of the GNU General Public         */
+;*   License along with this program; if not, write to the Free        */
+;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
+;*   MA 02111-1307, USA.                                               */
 ;*---------------------------------------------------------------------*/
-
-
 ;*---------------------------------------------------------------------*/
 ;*    serrano/prgm/project/bigloo/recette/vital.scm                    */
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Mon Nov  2 17:35:36 1992                          */
-;*    Last change :  Thu Apr  4 09:11:40 1996 (serrano)                */
+;*    Last change :  Mon Sep 21 16:39:20 1998 (serrano)                */
 ;*                                                                     */
 ;*    On tests les choses qui sont vraiment vital et sans lesquelles   */
 ;*    on ne peut rien faire du tout.                                   */
@@ -114,6 +112,12 @@
           revtype)))
    (revtype2 1 2 #f))
 
+;*---------------------------------------------------------------------*/
+;*    producer ...                                                     */
+;*---------------------------------------------------------------------*/
+(define (producer a b)
+   (values (+ a 1) (+ b 1)))
+   
 ;*---------------------------------------------------------------------*/
 ;*    Top level definition orders                                      */
 ;*---------------------------------------------------------------------*/
@@ -161,11 +165,18 @@
 ;*---------------------------------------------------------------------*/
 (define-struct point x y)
 
+;*---------------------------------------------------------------------*/
+;*    inline/class/generic                                             */
+;*---------------------------------------------------------------------*/
+(define-inline (inline x) x)
+(define-inline (class x) x)
+(define-inline (generic x) x)
+
 ;*---------------------------------------------------------------------*/
 ;*    test-vital ...                                                   */
 ;*---------------------------------------------------------------------*/
 (define (test-vital)
-   (test-module "vital" "vital.scm" #f)
+   (test-module "vital" "vital.scm")
    (test "true" #t (not #f))
    (test "true" #t (not (not 4)))
    (test "true" (not (eq? #t #f)) (not #f))
@@ -189,18 +200,7 @@
    (test "symbol" 't (string->symbol "T"))
    (let ((s "toto\"\\\ntiti"))
       (test "write" (vital:write s) s))
-   (let* ((s    "toto n'est pas content")
-	  (sp   "titi non plus")
-	  (l    (list s s s sp sp s sp sp 'toto 'toto '#(1 2 3) #\a #\a #t #f))
-	  (v    `#123(,l ,l ,l () ,(unspecified) 1.13 1.13 #a123
-			 (point 1 2) (point 2 1) #<0010> #<0011>))
-	  (vec  (make-vector 3 v))
-	  (rep  (obj->string v)))
-      (test "intext" (string->obj rep) v))
    (test "flonum" (real? (string->obj (obj->string 0.5))) #t)
-   (let* ((s (make-string 3 #\a))
-	  (l (list s s)))
-      (test "string->obj" (string->obj (obj->string l)) l))
    (let* ((append! (lambda (x y)
 		      (if (null? x)
 			  y
@@ -212,8 +212,19 @@
 	  (l1      '(1 2 3))
 	  (l2      '(4 5 6)))
       (test "do" (append! l1 l2) '(1 2 3 4 5 6)))
-   (test "let" (let ((x 1 2 3)) x) 3)
+   (test "let" (let ((x (begin 1 2 3))) x) 3)
    (test "hoist" (vital:hoist) #f)
+   (let* ((s (make-string 3 #\a))
+	  (l (list s s)))
+      (test "string->obj" (string->obj (obj->string l)) l))
+   (let* ((s    "toto n'est pas content")
+	  (sp   "titi non plus")
+	  (l    (list s s s sp sp s sp sp 'toto 'toto '#(1 2 3) #\a #\a #t #f))
+	  (v    `#(,l ,l ,l () ,(unspecified) 1.13 1.13 #a123
+		      (point 1 2) (point 2 1) #<0010> #<0011>))
+	  (vec  (make-vector 3 v))
+	  (rep  (obj->string v)))
+      (test "intext" (string->obj rep) v))
    (test "top level forms" (list order_foo1
 				 order_foo2
 				 order_foo3
@@ -228,4 +239,27 @@
 				 order_bar6
 				 order_bar7
 				 order_bar8)
-	 '(1 2 3 4 5 6 7 8)))
+	 '(1 2 3 4 5 6 7 8))
+   (test "multive-value-bind" (multiple-value-bind (a b c d)
+				 (values 1 2 3 4)
+				 (- a b c d))
+	 -8)
+   (test "multiple-value-bind"
+	 (multiple-value-bind (x y) (producer 1 2) (+ x y))
+	 5)
+   (test "call-with-values" (call-with-values (lambda () (values 1 2 3 4))
+					      (lambda (a b c d) (+ a b c d)))
+	 10)
+   (test "call-with-values" (call-with-values * -) -1)
+   (let ((b (let ((ptr-align (pragma::long "PTR_ALIGNMENT")))
+	       (-fx (bit-lsh 1 (+fx ptr-align 3)) ptr-align))))
+      (test "<< >>"  (let ((n (bit-lsh 1 b))
+			   (n-1 (bit-lsh 1 (-fx b 1)))
+			   (n-2 (bit-lsh 1 (-fx b 2))))
+			(and (>fx n n-1) (>fx n-1 n-2)))
+	    #t)))
+   
+			     
+		     
+
+
